function factorial_demo(N)
% function factorial_demo(N)
% calculates the factorial N!=1*2*3*.....*N-1*N for a positive integer N.
% The calculation is done in four different ways: while loop, for loop,
% vector solution and buildt-in function factorial.
% This function demonstrates the use of for and while loops in Matlab.
% It is part of the Matlab course for PhD Students 2010-2011:
% http://www.sinnesphysiologie.uni-oldenburg.de/50246.html
% written by Jutta Kretzberg, 11.12.2010

%% tests for correct input argument 

% interrupt program, if input is not a number or not positive:
if ~isnumeric(N) || N<=0
    error('Input must be a positive integer!')   
end
% give a warning, if input is no scalar:
if length(N)>1
    N=N(1);
    warning('Input should be a scalar. Only first value will be considered.') 
end
% give a warning, if input is no integer:
if round(N)~=N
    N=round(N)
    warning('Input should be an integer. Rounded value will be considered.')
end
% give a warning, if input is too large to calculate factorial reliably
if N>21
    warning('Input is too large to calculate factorial reliably, result will be in the correct order.')
end
% display value of N that will be used:
sprintf('Calculation of %u! starts now.',N)

%% while loop
c=1;                % initialize counter
res=1;              % initialize variable for result
while c<=N          % condition: repeat as long as counter is smaller or 
                    % equal to N
    res=res*c;      % calculate result of factorial for counter
    c=c+1;          % increase counter
end
sprintf('while: %u!=%u',N,res)  % display result

%% for loop
res=1;              % initialize variable for result
for c=1:N
    res=res*c;
end
sprintf('for: %u!=%u',N,res)  % display result

%% vector solution:
v=1:N;              % generate vector of numbers
res=prod(v);        % multiply all elements in one step
sprintf('vector: %u!=%u',N,res)  % display result

%% buildt-in function:
res=factorial(N);    
sprintf('buildt-in: %u!=%u',N,res)  % display result
