% make_VP_data
% script to generate data for PhD Matlab course

%% generate vector of 10 stimulus conditions, 
% each condition is presented 50 times 
s=1:10;                     % conditions 1 to 10
stim=repmat(s',50,1);       % replicate vector of conditions
stim_sorted=sortrows(stim);    % sort stimulus conditions

%% generate vector of stimulus detection: yes 1 or no 0

% stimulus 1-4: 90% correct
react1_4=rand(200,1)<0.9;   % generate 200 random numbers between 0 and 1. 
                            % If they are <0.9 the stimulus was detected,
                            % otherwise it was not detected
                            
% stimulus 5-6: 75% correct
react5_6=rand(100,1)<0.75   

% stimulus 7-8: 60% correct
react7_8=rand(100,1)<0.6

% stimulus 9: 50% correct
react9=rand(50,1)<0.5

% stimulus 10: 25% correct
react10=rand(50,1)<0.25

react_sorted=[react1_4;react5_6;react7_8;react9;react10]; %combine


%% generate reaction times:
% bimodal distribution of reaction times, all at least 0.2s long
% reaction times are assumed to be independent of stimulus

rt_long=abs(2*randn(100,1))+0.2;        % 100 long times     
rt_short=abs(0.5*randn(400,1))+0.2;     % 400 short times
rt_sorted=[rt_long;rt_short];           % combination
ind=randperm(500);                      % create random indices to mix
rt=rt_sorted(ind);                      % mix reaction times to make them
                                        % independent of stimulus


%% combine vectors and apply random order
VP_data_sorted=[stim_sorted, react_sorted, rt];  % combine sorted data

ind=randperm(500);                      % create random indices to mix
VP_data=VP_data_sorted(ind,:);          % mix rows of matrix to have random
                                        % order of stimuli


%% plot to check if everything worked fine

figure(1)
plot([stim_sorted, VP_data(:,1)])
legend('sorted','mixed')
title('stimulus')

figure(2)
plot([react_sorted, VP_data(:,2)])
legend('sorted','mixed')
title('detection')

figure(3)
plot([rt_sorted, VP_data(:,3)])
legend('sorted','mixed')
title('reaction time')
                   
save VP_data VP_data